'use client'
import { useEffect, useState } from "react";
import toast from 'react-hot-toast';
import useHandleConversationStore from "@/feature/messenger/store/useHandleConversationStore";
import useListContactStore from "@/feature/messenger/store/useListContactStore";
import useConfigChatStore from "@/feature/messenger/store/chat_store/useConfigChatStore";
import useConversationsStore from "@/feature/messenger/store/chat_store/useConversationsStore";
import { startConversationService } from "@/feature/messenger/services/chat/OptionsConversationsService";
import ConfimDialog from "@/feature/messenger/components/dialog/ConfimDialog";
import { Button, Modal, ModalBody, ModalContent, ModalFooter, ModalHeader, Select, SelectItem, Textarea } from "@nextui-org/react";
import { useTranslation } from "@/src/hooks/useTranslation";
import { getContactsNewConversationService, searchContactsService } from "@/feature/messenger/services/chat/OptionsMessageService";
import { ListConversationModel } from "@/feature/messenger/models/ListConversationModel";

const NewConversation = () => {

  const openModalNewConversation = useHandleConversationStore(state => state.openModalNewConversation);
  const handleOpenModalNewConversation = useHandleConversationStore(state => state.actions.handleOpenModalNewConversation);

  const [modalConfirm, setModalConfirm] = useState(false);
  const [loading, setLoading] = useState(false);
  const [contactSelected, setContactSelected] = useState({
    celular: '',
  });
  const [filter, setFilter] = useState('');
  //const listContact: any = useListContactStore(state => state.listContact);
  const [listContactFiltered, setListContactFiltered] = useState([]);
  const [listContactDefault, setListContactDefault] = useState([]);
  const [listTemplate, setListTemplate] = useState([]);
  const [templateSelected, setTemplateSelected] = useState<string[]>([]);
  const hadlerSelectContactOption = useListContactStore(state => state.hadlerSelectContactOption);
  const id_chatbot = useConfigChatStore(state => state.idChatbot);
  const [comment, setComment] = useState('');
  const actionsConversation = useConversationsStore(state => state.actions);
  const { trans } = useTranslation();
  const [isNumberFilter, setIsNumberFilter] = useState(false);

  useEffect(() => {
    if (openModalNewConversation) {
      hadlerSelectContactOption();
      getContactsNewConversationService(id_chatbot).then((res) => {
        setListContactFiltered(res.data.contacts);
        setListContactDefault(res.data.contacts);
        setListTemplate(res.data.template);
      });
    }
    setFilter('');
  }, [openModalNewConversation]);

  const changeChatClick = (e: any, chatlist: any) => {
    e.stopPropagation();
    setModalConfirm(true);
    setContactSelected(chatlist);
  }

  const handlerFilterSearch = (e: any) => {
    let value = e.target.value;
    searchContactsService(id_chatbot,value).then((res) => {
      if (res.success == true && res.data.length > 0) {
        let filterArray = res.data;
        setListContactFiltered(filterArray);
      }
    });
    if (value == '') {
      setListContactFiltered(listContactDefault);
    }
    setFilter(value);
    setIsNumberFilter(value.match(/^\d+$/) ? true : false);
  }

  const handlerConfirm = async () => {
    if (comment.trim() == '') {
      toast.error(trans("modal_conversations_start_alert_add_comment_title"));
      return
    }
    const celular = Object.keys(contactSelected).length === 0 ? "" : contactSelected?.celular;
    if (celular.trim() == '') {
      toast.error(trans("modal_conversations_start_alert_add_contact_title"));
      return
    }
    if (templateSelected.length == 0 && listTemplate.length > 0) {
      toast.error(trans("modal_conversations_start_alert_add_template_title"));
      return
    }
    setLoading(true);
    const res = await startConversationService(id_chatbot, celular, comment,'');
    if (res.success == true && res.data.status == false) {
      toast.success(trans("modal_conversations_start_alert_has_conversation_title") + res.data.login);
      setLoading(false);
      setModalConfirm(false);
      handleOpenModalNewConversation
      setComment('');
      return;
    }
    if (res.success == true) {
      toast.success(trans("modal_conversations_start_alert_start_success_title"));
      try {
        let tags = [];
        try {
          tags = res.data.conversation[0].tags;
        } catch (error) {
          tags = [];
        }
        
        const newConversation : ListConversationModel = {
          sesion: res.data.message.sesion,
          nombre: res.data.message.nombre,
          rsocial: res.data.message.rsocial,
          conversacion: res.data.message.conversacion,
          tipomensaje: res.data.message.tipomensaje,
          sinLeer: 0,
          alerta_demora: "",
          fecha: res.data.message.fecha_sistema,
          tags: tags
        };
        actionsConversation.setSelectedConversation(newConversation);
        actionsConversation.addNewConversation(newConversation);
        setTemplateSelected([]);
        setComment('');
        handleOpenModalNewConversation();
      } catch (error) {
        toast.error(trans("modal_conversations_start_alert_start_error_title"));
      }
    } else {
      toast.error(trans("modal_conversations_start_alert_start_error_title"));
    }
    setLoading(false);
    setModalConfirm(false);
    handleOpenModalNewConversation
    setComment('');
  }

  const handlerConfirmButton = async () => {
    const celular = filter;
    if (comment.trim() == '') {
      toast.error(trans("modal_conversations_start_alert_add_comment_title"));
      return
    }
    if (celular.trim() == '') {
      toast.error(trans("modal_conversations_start_alert_add_contact_title"));
      return
    }
    if (templateSelected.length == 0 && listTemplate.length > 0) {
      toast.error(trans("modal_conversations_start_alert_add_template_title"));
      return
    }
    setLoading(true);
    const res = await startConversationService(id_chatbot, celular, comment,'');
    if (res.success == true && res.data.status == false) {
      toast.success(trans("modal_conversations_start_alert_has_conversation_title") + res.data.login);
      setLoading(false);
      setModalConfirm(false);
      handleOpenModalNewConversation
      setComment('');
      setTemplateSelected([]);
      return;
    }
    
    if (res.success == true) {
      toast.success(trans("modal_conversations_start_alert_start_success_title"));
      try {
        const newConversation : ListConversationModel = {
          sesion: res.data.message.sesion,
          nombre: res.data.message.nombre,
          rsocial: res.data.message.rsocial,
          conversacion: res.data.message.conversacion,
          tipomensaje: res.data.message.tipomensaje,
          sinLeer: 0,
          alerta_demora: "",
          fecha: res.data.message.fecha_sistema,
          tags: []
        };
        actionsConversation.setSelectedConversation(newConversation);
        actionsConversation.addNewConversation(newConversation);
        setTemplateSelected([]);
        setComment('');
        handleOpenModalNewConversation();
      } catch (error) {
        toast.error(trans("modal_conversations_start_alert_start_error_title"));
      }
    } else {
      toast.error(trans("modal_conversations_start_alert_start_error_title"));
    }
    setLoading(false);
    setModalConfirm(false);
    handleOpenModalNewConversation
    setComment('');
    setTemplateSelected([]);
  }

  const handleSelectTemplate = (keys: any) => {
    setTemplateSelected(Array.from(keys as Set<string>));
    const key = Array.from(keys as Set<string>);
    const id = key[0];
    if (id != undefined) {
      const template : any = listTemplate.find((item: any) => item.id == id);
      if (template) {
        setComment(template.plantilla_aprobada);
        return
      }
    }
    setComment('');
  }

  const itemTemplate = (item: any) => {
    return (
      <div key={item.id}>
        <strong>{item.nombre_plantilla}</strong> : {item.plantilla_aprobada}
      </div>
    );
  }

  return (
    <>
      <Modal isOpen={openModalNewConversation} onOpenChange={handleOpenModalNewConversation} size="xl">

        <ModalContent>
          {(onClose) => (
            <>
              <ModalHeader>
                {trans('modal_conversations_start_title')}
              </ModalHeader>
              <ModalBody>
                <div className="w-full">
                  <div className="relative w-full">
                    <div className="absolute inset-y-0 start-0 flex items-center ps-3 pointer-events-none">
                       <span>@</span>
                    </div>
                    <input type="text" value={filter} onChange={handlerFilterSearch} onKeyDown={(e) => { e.key === 'Enter' && e.preventDefault(); }} className="focus:outline-none focus:ring-0 focus:border-transparent bg-gray-100 border border-gray-200 text-gray-900 text-sm rounded-lg block w-full ps-10 p-2.5" placeholder={trans('modal_conversations_start_placeholder_search_contact')} />
                  </div>
                </div>
                <ul className="h-96 p-2 overflow-x-hidden overflow-y-auto w-full">
                  {listContactFiltered.length > 0 && listContactFiltered.map((chatlist: any, i: any) => {
                    return (
                      <li className={`${1 === chatlist.id ? "active" : ""} cursor-pointer w-full hover p-1 m-1`} data-to="blank" key={i} onClick={(e) => changeChatClick(e, chatlist)}>
                        <div className="flex flex-row gap-4 divide-y-1">
                          <div
                            className={`profile  ${chatlist.onlineStatus} size-12`}
                            style={{
                              backgroundImage: `url('${process.env.ASSET_PREFIX || ''}/chat/assets/images/contact/whatsapp.png')`,
                              backgroundSize: "cover",
                              backgroundPosition: "center",
                              display: "block",
                            }}>
                            <img className="bg-img" src={`${process.env.ASSET_PREFIX}/chat/assets/images/contact/whatsapp.png`} alt="Avatar" style={{ display: "none" }} />
                          </div>
                          <div className="details w-full">
                            <h5 className="font-bold text-md">{chatlist.nombre || ""}</h5>
                            <h6 className="text-sm">{chatlist.celular || ""}</h6>
                          </div>
                        </div>
                      </li>
                    );
                  })}
                </ul>
                <div className={`p-2 ${listTemplate.length > 0 ? 'block' : 'hidden'}`}>
                  <Select color="primary" selectionMode="single" selectedKeys={templateSelected} 
                    label={trans('modal_conversations_start_label_template')}
                    value={templateSelected}
                    onSelectionChange={(keys) => handleSelectTemplate(keys)}
                    items={listTemplate}
                    renderValue={(value:any) => {
                      const item: any = listTemplate.find((item: any) => item.id == value[0].key);
                      if (item) {
                      
                      return itemTemplate(item);
                    }
                    }}
                    >
                    {listTemplate.map((item: any, i: any) => {
                      return <SelectItem key={item.id} value={item.id}
                      startContent={
                        <strong>{item.nombre_plantilla} : </strong>
                      }
                      >{item.plantilla_aprobada}</SelectItem>
                    })}
                  </Select>
                </div>
                <div className={`p-4`}>
                <Textarea
                    isRequired
                    label={trans('modal_conversations_start_label_commentary')}
                    labelPlacement="outside"
                    placeholder={trans('modal_conversations_start_label_commentary')}
                    value={comment}
                    variant="bordered"
                    onChange={(e) => setComment(e.target.value)}
                    disableAnimation
                    classNames={{
                      base: "max-w-full",
                      input: "resize-y min-h-[40px]",
                    }}

                  />
                </div>
                <ModalFooter>
                  <Button className={`${isNumberFilter ? 'block' : 'hidden'}`} color="primary" onClick={handlerConfirmButton}>{trans('modal_conversations_start_title')}</Button>
                </ModalFooter>
              </ModalBody>
            </>
          )}
        </ModalContent>
      </Modal>
      <ConfimDialog
        openModal={modalConfirm}
        setOpenModal={setModalConfirm}
        textConfirm={trans('modal_conversations_start_title')}
        textDescription={trans('modal_conversations_start_confirm_title')}
        executeConfirm={handlerConfirm}
        loading={loading}
        contact={contactSelected.celular}
      />
    </>
  )
}

export default NewConversation
